@@ -20,7 +20,7 @@ MaxQdataconvert <- function(pgfilename, IDname = "Majority.protein.IDs",
     inf <- try(P.G.extract(data$protein_IDs, justID = justID,
                            status1 = status1, ENTRY1 = ENTRY1,
                            verbose = verbose-1));
-    if (class(inf) != "try-error") {
+    if (any(class(inf) %in% "try-error")) { #200627
       inf <- data.frame(inf[ ,1:3], stringsAsFactors = FALSE);
       colnames(inf) <- c("db.type", "ori.ID", "ENTRY.NAME");
       NEXTtoIDmatch = TRUE;
@@ -211,6 +211,7 @@ P.G.extract <- function(inf, ncol = 4,
 #evalue lower means more rigorous;verbose:0 no verbose:1 have
 #190601 reset the default working directory
 #190605 add alternative solution without use blast+
+#200602 fix a bug in step 2
 
 #db1.path="c:/workingdirectory/human-uniprot-20180108.fasta"
 #db2.path="c:/workingdirectory/mouse-uniprot-20180108.fasta"
@@ -247,21 +248,21 @@ ID_match <- function(data, db1.path = NULL, db2.path = NULL,
   #db1.folder <- gsub(paste0("(",out.folder,").*"), "\\1", db1.path);
   if (all(out.folder != db1.folder)) stop ("db1.path is not in the out.folder");
   Alignment = FALSE; #190605
+  Continue = TRUE; #200626
   #190605
   if (is.null(blast.path)) {
-    message("blast.path is null.\n");
+    message("blast.path is null.\n Use pairwiseAlignment function, it will take lots of time.");
+    Alignment <- TRUE; #200626 remove the question function
     #cat("blast.path is null.\n");
-    if (question("Do you want to do ID_match without using blast+ software?"))
-      {if(question("It will take large amouts of time.  Are you sure?"))
-        Alignment <- TRUE else stop("Please give the blast.path and re-run the function.");}
-    else stop("Please give the blast.path and re-run the function.");
   } else if (!dir.exists(blast.path)) {
     message("blast.path is not exists.\n");
     #cat("blast.path is not exists.\n");
     if (question("Do you want to do ID_match without using blast+ software?"))
       {if(question("It will take large amouts of time. Are you sure?"))
         Alignment <- TRUE else stop("Please give the correct blast.path and re-run the function.");
-    } else stop("Please give the correct blast.path and re-run the function.");
+    } else { if (question("Continue to run?"))
+      Continue = FALSE else stop("Please give the correct blast.path and re-run the function.");
+    }#200626
   }#190605
   my_sequences <- .uniprot_database(input_file = db1.path);
   if(class(my_sequences) == "try-error") #190605
@@ -313,7 +314,7 @@ ID_match <- function(data, db1.path = NULL, db2.path = NULL,
     data_withgn <- merge(datano1, database2[ ,c('Uniprot.ID', 'GN')],
                        by.x = 'ori.ID',by.y = 'Uniprot.ID',sort = FALSE);
     nogn <- which(data_withgn$GN == "") #181210
-    data_withgn <- data_withgn[-nogn, ] #181210
+    if(length(nogn) != 0 ) data_withgn <- data_withgn[-nogn, ] #181210 #200602
     # extract GN information
     data_GN <- gsub("(.*)","^\\1", as.character(data_withgn$GN), perl = TRUE);
     #limitation maxium matched protein ID number is 14
@@ -351,7 +352,7 @@ ID_match <- function(data, db1.path = NULL, db2.path = NULL,
         name <- data_withgn$ori.ID[j];
         ori_seq <- as.character(database2_seq[names(database2_seq) == name]);
         #remove the unregular amino acid
-        aa <- unlist(Biostrings::strsplit(unname(ori_seq),"")); #190605
+        aa <- unlist(strsplit(unname(ori_seq),"")); #190605 #200626 use base::strsplit instead of Biostrings::strsplit
         aa <- aa[aa %in% c("A","C","D","E","F","G","H","I",
                            "K","L","M","N","P","Q","R","S",
                            "T","V","W","Y")]; #190605
@@ -368,7 +369,7 @@ ID_match <- function(data, db1.path = NULL, db2.path = NULL,
                                                        gapExtension = 0.5,
                                                        scoreOnly = TRUE), silent = TRUE);
           if (class(pwalign) == "try-error") {
-            aa <- unlist(Biostrings::strsplit(unname( as.character(similar_seq[k]) ),""));
+            aa <- unlist(strsplit(unname( as.character(similar_seq[k]) ),"")); #200626
             aa <- aa[aa %in% c("A","C","D","E","F","G","H","I",
                                "K","L","M","N","P","Q","R","S",
                                "T","V","W","Y")];
@@ -420,7 +421,7 @@ ID_match <- function(data, db1.path = NULL, db2.path = NULL,
       #if("micropan" %in% rownames(installed.packages()) == FALSE)
       #{install.packages("micropan")}
       #suppressMessages(library("micropan"))
-      if (!Alignment) { #190605
+      if (!Alignment & Continue) { #190605
         log.fil <- file.path(out.folder, "log.txt");
         db.fil <- file.path(out.folder, "blastDB");
         command <- paste("makeblastdb -logfile", log.fil,
@@ -480,11 +481,12 @@ ID_match <- function(data, db1.path = NULL, db2.path = NULL,
       }#190605
       #190605
       if (Alignment) {
+        Continue = FALSE; #200626
         type3_results <- list();
         for (j in 1:length(data_ori.ID)) {
           name <- data_ori.ID[j];
           ori_seq <- as.character(database2_seq[names(database2_seq) == name]);
-          aa <- unlist(Biostrings::strsplit(unname(ori_seq),""));
+          aa <- unlist(strsplit(unname(ori_seq),"")); #200626
           aa <- aa[aa %in% c("A","C","D","E","F","G","H","I",
                              "K","L","M","N","P","Q","R","S",
                              "T","V","W","Y")];
@@ -500,7 +502,7 @@ ID_match <- function(data, db1.path = NULL, db2.path = NULL,
                                                          gapExtension = 0.5,
                                                          scoreOnly = TRUE), silent = TRUE);
             if (class(pwalign) == "try-error") {
-              aa <- unlist(Biostrings::strsplit(unname(as.character(database1_seq[k])),""));
+              aa <- unlist(strsplit(unname(as.character(database1_seq[k])),"")); #200626
               aa <- aa[aa %in% c("A","C","D","E","F","G","H","I",
                                  "K","L","M","N","P","Q","R","S",
                                  "T","V","W","Y")];
